==> apache-iotdb-1.3.6-source-release.zip: apache-iotdb-1.3.6/iotdb-core/datanode/src/main/java/org/apache/iotdb/db/schemaengine/schemaregion/SchemaRegionParams.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.db.schemaengine.schemaregion;

import org.apache.iotdb.commons.consensus.SchemaRegionId;
import org.apache.iotdb.commons.path.PartialPath;
import org.apache.iotdb.db.schemaengine.rescon.ISchemaEngineStatistics;

public class SchemaRegionParams implements ISchemaRegionParams {

  private final PartialPath database;

  private final SchemaRegionId schemaRegionId;

  private final ISchemaEngineStatistics schemaEngineStatistics;

  public SchemaRegionParams(
      PartialPath database,
      SchemaRegionId schemaRegionId,
      ISchemaEngineStatistics schemaEngineStatistics) {
    this.database = database;
    this.schemaRegionId = schemaRegionId;
    this.schemaEngineStatistics = schemaEngineStatistics;
  }

  @Override
  public PartialPath getDatabase() {
    return database;
  }

  @Override
  public SchemaRegionId getSchemaRegionId() {
    return schemaRegionId;
  }

  @Override
  public ISchemaEngineStatistics getSchemaEngineStatistics() {
    return schemaEngineStatistics;
  }
}

==> apache-iotdb-2.0.6-source-release.zip: apache-iotdb-2.0.6/iotdb-core/datanode/src/main/java/org/apache/iotdb/db/schemaengine/schemaregion/SchemaRegionParams.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.db.schemaengine.schemaregion;

import org.apache.iotdb.commons.consensus.SchemaRegionId;
import org.apache.iotdb.db.schemaengine.rescon.ISchemaEngineStatistics;

public class SchemaRegionParams implements ISchemaRegionParams {

  private final String database;

  private final SchemaRegionId schemaRegionId;

  private final ISchemaEngineStatistics schemaEngineStatistics;

  public SchemaRegionParams(
      final String database,
      final SchemaRegionId schemaRegionId,
      final ISchemaEngineStatistics schemaEngineStatistics) {
    this.database = database;
    this.schemaRegionId = schemaRegionId;
    this.schemaEngineStatistics = schemaEngineStatistics;
  }

  @Override
  public String getDatabase() {
    return database;
  }

  @Override
  public SchemaRegionId getSchemaRegionId() {
    return schemaRegionId;
  }

  @Override
  public ISchemaEngineStatistics getSchemaEngineStatistics() {
    return schemaEngineStatistics;
  }
}
